@@ -15,7 +15,7 @@ pub trait Executor {
     ///
     /// Dropping the handle will cancel the future. You can call `detach()` to let it
     /// run without waiting for its completion.
-    fn spawn<T>(&self, f: Pin<Box<dyn Future<Output = T> + Send>>) -> Box<dyn Task<T>>;
+    fn spawn<T: Send>(&self, f: Pin<Box<dyn Future<Output = T> + Send>>) -> Box<dyn Task<T>>;
 }
 
 /// A common interface for spawning non-Send futures on top of an executor, on the current thread
@@ -31,14 +31,14 @@ pub trait LocalExecutor {
 #[async_trait]
 pub trait BlockingExecutor {
     /// Convert a blocking task into a future, spawning it on a decicated thread pool
-    async fn spawn_blocking<T>(&self, f: Box<dyn FnOnce() -> T + Send>) -> T;
+    async fn spawn_blocking<T: Send>(&self, f: Box<dyn FnOnce() -> T + Send>) -> T;
 }
 
 impl<E: Deref> Executor for E
 where
     E::Target: Executor,
 {
-    fn spawn<T>(&self, f: Pin<Box<dyn Future<Output = T> + Send>>) -> Box<dyn Task<T>> {
+    fn spawn<T: Send>(&self, f: Pin<Box<dyn Future<Output = T> + Send>>) -> Box<dyn Task<T>> {
         self.deref().spawn(f)
     }
 }
@@ -57,7 +57,7 @@ impl<E: Deref + Sync> BlockingExecutor for E
 where
     E::Target: BlockingExecutor + Sync,
 {
-    async fn spawn_blocking<T>(&self, f: Box<dyn FnOnce() -> T + Send>) -> T {
+    async fn spawn_blocking<T: Send>(&self, f: Box<dyn FnOnce() -> T + Send>) -> T {
         self.deref().spawn_blocking(f).await
     }
 }
